using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DataPresenter;
using Infragistics.Controls.Editors;
using Infragistics.Windows.Editors;
using Infragistics.Windows;

namespace XamDataCards_sample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public ObservableCollection<Item> Items { get; set; }

        public MainWindow()
        {
            InitializeComponent();

            Items = new ObservableCollection<Item>()
            {
                new Item("Item 1", 8415, 12.5),
                new Item("Item 2", 5801, 101.3),
                new Item("Item 3", 2013, 10.0),
                new Item("Item 4", 1147, 54.5),
                new Item("Item 5", 1950, 71.7)
            };
            
            this.DataContext = this;
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            // Add new Field with XamMultiColumnComboEditor to the XamDataCards's default FieldLayout
            //
            var field = GetComboEditor("new field", "new field label", Items, "Id", null);
            dataCards.DefaultFieldLayout.Fields.Add(field);
        }
 
        public static Field GetComboEditor(string name, string label, object values, string displayMemberPath, IValueConverter converter, ValueConstraint constraint = null, string tooltip = null)
        {
            var editor = new FrameworkElementFactory(typeof(XamMultiColumnComboEditor));
            editor.SetValue(XamMultiColumnComboEditor.AutoGenerateColumnsProperty, false);
            editor.SetValue(XamMultiColumnComboEditor.AllowMultipleSelectionProperty, false);
            editor.SetValue(XamMultiColumnComboEditor.ItemsSourceProperty, values);
            editor.SetValue(XamMultiColumnComboEditor.DisplayMemberPathProperty, displayMemberPath);
            editor.SetValue(XamMultiColumnComboEditor.SelectedItemsResetButtonVisibilityProperty, Visibility.Collapsed);

            // BUILD COLUMNS AND ATTACH TO THE editor HERE SOME HOW?
            var ctrlTemplate = new ControlTemplate(typeof(CellValuePresenter))
            {
                VisualTree = editor
            };

            var loadedCellValuePresenterHandler = new RoutedEventHandler((se, ev) =>
            {
                var cvp = (se as CellValuePresenter);
                var multiCombo = Utilities.GetDescendantFromType(cvp, typeof(XamMultiColumnComboEditor), false) as XamMultiColumnComboEditor;
                if (multiCombo == null)
                    return;

                multiCombo.Columns.Add(new TextComboColumn() { Key = "Name" });
            });
            
            var cvpStyle = new Style(typeof(CellValuePresenter));
            cvpStyle.Setters.Add(new EventSetter(Control.LoadedEvent, loadedCellValuePresenterHandler));
            cvpStyle.Setters.Add(new Setter(Control.TemplateProperty, ctrlTemplate));
            
            return new Field
            {
                Name = name,
                Label = label,
                IsExpandable = false,
                ToolTip = tooltip,

                DataType = typeof(object),
                Settings =
               {
                   CellValuePresenterStyle = cvpStyle,
               }
            };
        }

    }
}
